//
//  TESTProgressViewController.m
//
//  Created by Thomas Wolters on 19/10/15.
//  Copyright © 2015 fluodmobile. All rights reserved.
//

#import "Demo5AnimationLayerReplicatorViewController.h"
#import "Demo5AnimationLayerReplicatorView.h"
#import "TESTSliderCell.h"
#import "TESTButtonCell.h"

#define ITEM_COUNT 10000

@interface Demo5AnimationLayerReplicatorViewController () <UITableViewDelegate, UITableViewDataSource, TESTSliderCellDelegate>
@property (nonatomic, strong) NSTimer* timer;
@property (nonatomic, assign) int progress;
@property (nonatomic, strong) Demo5AnimationLayerReplicatorView* viewProgress;
@property (nonatomic, assign) float time;
@end

@implementation Demo5AnimationLayerReplicatorViewController

-(void)loadView{
    self.viewProgress = [Demo5AnimationLayerReplicatorView new];
    self.view = self.viewProgress;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    self.viewProgress.tableView.delegate = self;
    self.viewProgress.tableView.dataSource = self;
    [self.viewProgress.tableView registerClass:[TESTSliderCell class] forCellReuseIdentifier:CELL_SLIDER];
    [self.viewProgress.tableView registerClass:[TESTButtonCell class] forCellReuseIdentifier:CELL_BUTTON];
    
    self.time = 0.5f;
}

-(NSTimer*)createTimer{
    return [NSTimer scheduledTimerWithTimeInterval:0.5f target:self selector:@selector(actionTimer:) userInfo:nil repeats:NO];
}

-(void)viewDidAppear:(BOOL)animated{
    self.timer = [self createTimer];
    [super viewDidAppear:animated];

}

-(void)actionTimer:(id)sender{
    [self.timer invalidate];
    self.progress++;
    [self.viewProgress updateProgress:(self.progress / ITEM_COUNT) text:[NSString stringWithFormat:@"%i", self.progress]];
    if (self.progress < ITEM_COUNT){
        self.timer = [self createTimer];
    }
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    switch (section) {
        case 0:
            return 10;
        case 1:
            return 3;
    }
    return 0;
}

-(NSInteger)numberOfSectionsInTableView:(UITableView *)tableView{
    return 2;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath{
    switch (indexPath.section) {
        case 0:
            return CELL_SLIDER_HEIGHT;
        case 1:
            return CELL_BUTTON_HEIGHT;
    }
    return CELL_SLIDER_HEIGHT;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    switch (indexPath.section) {
        case 0:{
            TESTSliderCell* cell = [tableView dequeueReusableCellWithIdentifier:CELL_SLIDER];
            cell.delegate = self;
            switch (indexPath.row) {
                case 0:
                    [cell setAttribute:@"scaleX" value:self.viewProgress.scaleX minValue:1.0f maxValue:100 index:indexPath.row];
                    break;
                case 1:
                    [cell setAttribute:@"time per Element" value:self.time minValue:0.0f maxValue:5 index:indexPath.row];
                    break;
                case 2:
                    [cell setAttribute:@"Instance Delay" value:self.viewProgress.instanceDelay minValue:0.0f maxValue:5 index:indexPath.row];
                    break;
                case 3:
                    [cell setAttribute:@"Instance Count" value:self.viewProgress.instanceCount minValue:0.0f maxValue:200 index:indexPath.row];
                    break;
                case 4:
                    [cell setAttribute:@"Element Dimension" value:self.viewProgress.elementDimension minValue:0.0f maxValue:50 index:indexPath.row];
                    break;
                case 5:
                    [cell setAttribute:@"Element Angle" value:self.viewProgress.elementAngle minValue:0.0f maxValue:1 index:indexPath.row];
                    break;
                case 6:
                    [cell setAttribute:@"Transition3D X" value:self.viewProgress.transitionX minValue:0.0f maxValue:10 index:indexPath.row];
                    break;
                case 7:
                    [cell setAttribute:@"Transition3D Y" value:self.viewProgress.transitionY minValue:0.0f maxValue:10 index:indexPath.row];
                    break;
                case 8:
                    [cell setAttribute:@"Transition3D Z" value:self.viewProgress.transitionZ minValue:0.0f maxValue:10 index:indexPath.row];
                    break;
                case 9:
                    [cell setAttribute:@"Corner Radius" value:self.viewProgress.cornerRadius minValue:0.0f maxValue:self.viewProgress.elementDimension index:indexPath.row];
                    break;
                default:
                    break;
            }
            return cell;
        }
            break;
        case 1:{
            TESTButtonCell* cell = [tableView dequeueReusableCellWithIdentifier:CELL_BUTTON];
            switch (indexPath.row) {
                case 0:
                    [cell setTitle:@"Lade Szenario Flower" scenario:TESTAnimationScenarioFlower];
                    break;
                case 1:
                    [cell setTitle:@"Lade Szenario Pulse" scenario:TESTAnimationScenarioPulse];
                    break;
                case 2:
                    [cell setTitle:@"Reset" scenario:TESTAnimationScenarioDefault];
                    break;
                default:
                    break;
            }
            return cell;
        }
            break;
        default:
            break;
    }
    return nil;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    switch (indexPath.section) {
        case 1:
            switch (indexPath.row) {
                case 0:
                    [self.viewProgress setAnimationScenario:TESTAnimationScenarioFlower];
                    break;
                case 1:
                    [self.viewProgress setAnimationScenario:TESTAnimationScenarioPulse];
                    self.time = 0.12f;
                    [self actionTimer:nil];
                    break;
                case 2:
                    [self.viewProgress setAnimationScenario:TESTAnimationScenarioDefault];
                    [self loadView];
                    [self viewDidLoad];
                    [self viewDidAppear:YES];
                    break;
                default:
                    break;
            }
            break;
        default:
            break;
    }
}

-(void)userDidSelectValue:(float)value attribute:(NSString*)attribute index:(long)index{
    switch (index) {
        case 0:
            self.viewProgress.scaleX = value;
            break;
        case 1:
            self.time = value;
            [self actionTimer:nil];
            break;
        case 2:
            self.viewProgress.instanceDelay = value;
            break;
        case 3:
            self.viewProgress.instanceCount = value;
            break;
        case 4:
            self.viewProgress.elementDimension = value;
            break;
        case 5:
            self.viewProgress.elementAngle = value;
            break;
        case 6:
            self.viewProgress.transitionX = value;
            break;
        case 7:
            self.viewProgress.transitionY = value;
            break;
        case 8:
            self.viewProgress.transitionZ = value;
            break;
        case 9:
            self.viewProgress.cornerRadius = value;
            break;
        default:
            break;
    }
}

@end
